%define name lam
%define version 6.5.5
%define release 3mdk
%define lib_name_orig liblam
%define lib_major 0
%define lib_name %{lib_name_orig}%{lib_major}

Summary: The LAM (Local Area Multicomputer) programming environment.
Name: %{name}
Version: %{version}
Release: %{release}
License: BSD
Group: Development/Other
Source: lam-%{version}.tar.bz2
Source1: lam.sh
Source2: lam.csh
URL: http://www.lam-mpi.org/
BuildRoot: %{_tmppath}/%{name}-root
Prefix: %{_prefix}
BuildRequires: gcc-g77 fileutils perl

%description 
LAM (Local Area Multicomputer) is an Message-Passing Interface (MPI)
programming environment and development system for heterogeneous
computers on a network. With LAM/MPI, a dedicated cluster or an
existing network computing infrastructure can act as one parallel
computer to solve one problem. LAM/MPI is considered to be "cluster
friendly" because it offers daemon-based process startup/control as
well as fast client-to-client message passing protocols. LAM/MPI can
use TCP/IP and/or shared memory for message passing (different RPMs
are supplied for this -- see the main LAM website at
http://www.mpi.nd.edu/lam/ for details).<

LAM features a full implementation of MPI version 1 (with the
exception that LAM does not support cancelling of sends), and much of
version 2. Compliant applications are source code portable between LAM
and any other implementation of MPI. In addition to meeting the
standard, LAM/MPI offers extensive monitoring capabilities to support
debugging. Monitoring happens on two levels: On one level, LAM/MPI has
the hooks to allow a snapshot of a process and message status to be
taken at any time during an application run. The status includes all
aspects of synchronization plus datatype map/signature, communicator
group membership and message contents (see the XMPI application on the
main LAM website). On the second level, the MPI library can produce a
cumulative record of communication, which can be visualized either at
runtime or post-mortem.

%package -n %{name}-doc
Summary: Documentation for developing programs that will use lam-mpi
Group: Development/Other
#Requires: %{name} = %{version}-%{release}

%description -n %{name}-doc
LAM (Local Area Multicomputer) is an Message-Passing Interface (MPI)
programming environment and development system for heterogeneous
computers on a network. With LAM/MPI, a dedicated cluster or an
existing network computing infrastructure can act as one parallel
computer to solve one problem. LAM/MPI is considered to be "cluster
friendly" because it offers daemon-based process startup/control as
well as fast client-to-client message passing protocols. LAM/MPI can
use TCP/IP and/or shared memory for message passing (different RPMs
are supplied for this -- see the main LAM website at
http://www.mpi.nd.edu/lam/ for details).<

LAM features a full implementation of MPI version 1 (with the
exception that LAM does not support cancelling of sends), and much of
version 2. Compliant applications are source code portable between LAM
and any other implementation of MPI. In addition to meeting the
standard, LAM/MPI offers extensive monitoring capabilities to support
debugging. Monitoring happens on two levels: On one level, LAM/MPI has
the hooks to allow a snapshot of a process and message status to be
taken at any time during an application run. The status includes all
aspects of synchronization plus datatype map/signature, communicator
group membership and message contents (see the XMPI application on the
main LAM website). On the second level, the MPI library can produce a
cumulative record of communication, which can be visualized either at
runtime or post-mortem.

This package provides the documentation needed to develop
applications using the lam libraries.

%package -n %{lib_name}-devel
Summary: Headers for developing programs that will use lam-mpi
Group: Development/Other
#Requires: %{name} = %{version}-%{release}

%description -n %{lib_name}-devel
LAM (Local Area Multicomputer) is an Message-Passing Interface (MPI)
programming environment and development system for heterogeneous
computers on a network. With LAM/MPI, a dedicated cluster or an
existing network computing infrastructure can act as one parallel
computer to solve one problem. LAM/MPI is considered to be "cluster
friendly" because it offers daemon-based process startup/control as
well as fast client-to-client message passing protocols. LAM/MPI can
use TCP/IP and/or shared memory for message passing (different RPMs
are supplied for this -- see the main LAM website at
http://www.mpi.nd.edu/lam/ for details).<

LAM features a full implementation of MPI version 1 (with the
exception that LAM does not support cancelling of sends), and much of
version 2. Compliant applications are source code portable between LAM
and any other implementation of MPI. In addition to meeting the
standard, LAM/MPI offers extensive monitoring capabilities to support
debugging. Monitoring happens on two levels: On one level, LAM/MPI has
the hooks to allow a snapshot of a process and message status to be
taken at any time during an application run. The status includes all
aspects of synchronization plus datatype map/signature, communicator
group membership and message contents (see the XMPI application on the
main LAM website). On the second level, the MPI library can produce a
cumulative record of communication, which can be visualized either at
runtime or post-mortem.

This package provides the static libraries and header files needed to compile
applications using the lam libraries.

%package -n %{name}-runtime
Summary: LAM runtime environment for executing parallel programs.
Group: Development/Other
#Requires: %{name} = %{version}-%{release}

%description -n %{name}-runtime
LAM runtime environment for executing parallel programs.
LAM is an implementation of the Message Passing Interface (MPI)
protocol commonly used in parallel processing applications.

%prep
%setup -q

%build
%configure --sysconfdir=%{_sysconfdir}/lam \
	--with-rpi=usysv \
	--with-rsh=/usr/bin/rsh
make all

%install
rm -rf $RPM_BUILD_ROOT
make DESTDIR=$RPM_BUILD_ROOT install


pushd $RPM_BUILD_ROOT
rm -f usr/include/mpi++.h
ln -s mpi2c++/mpi++.h usr/include/mpi++.h

# balky has buildroot paths in the binary
perl -pi -e "s|(.*=).*hcp|\1/usr/bin/hcp|g" usr/bin/balky

mkdir -p $RPM_BUILD_ROOT/%{_sysconfdir}/profile.d
install -m 755 %SOURCE1 $RPM_BUILD_ROOT/%{_sysconfdir}/profile.d/
install -m 755 %SOURCE2 $RPM_BUILD_ROOT/%{_sysconfdir}/profile.d/
popd

%clean
#rm -rf $RPM_BUILD_ROOT


#%files
#%defattr(-,root,root)
#%doc LICENSE
#%{_libdir}/*.so.*

#%dir %{_sysconfdir}/lam/
#%config(noreplace) %{_sysconfdir}/lam
#%config(noreplace) %{_sysconfdir}/profile.d/*
#%{_bindir}/*
#%{_mandir}/*/*
#%{_includedir}/*
#%{_libdir}/*

%files -n %{name}-doc
%defattr(-,root,root)
%doc LICENSE HISTORY INSTALL README RELEASE_NOTES romio/doc/users-guide.ps.gz
%{_mandir}/man3/MPIO_Request_c2f.3.bz2
%{_mandir}/man3/MPIO_Request_f2c.3.bz2
%{_mandir}/man3/MPIO_Test.3.bz2
%{_mandir}/man3/MPIO_Wait.3.bz2
%{_mandir}/man3/MPI_Abort.3.bz2
%{_mandir}/man3/MPI_Address.3.bz2
%{_mandir}/man3/MPI_Allgather.3.bz2
%{_mandir}/man3/MPI_Allgatherv.3.bz2
%{_mandir}/man3/MPI_Allreduce.3.bz2
%{_mandir}/man3/MPI_Alltoall.3.bz2
%{_mandir}/man3/MPI_Alltoallv.3.bz2
%{_mandir}/man3/MPI_Attr_delete.3.bz2
%{_mandir}/man3/MPI_Attr_get.3.bz2
%{_mandir}/man3/MPI_Attr_put.3.bz2
%{_mandir}/man3/MPI_Barrier.3.bz2
%{_mandir}/man3/MPI_Bcast.3.bz2
%{_mandir}/man3/MPI_Bsend.3.bz2
%{_mandir}/man3/MPI_Bsend_init.3.bz2
%{_mandir}/man3/MPI_Buffer_attach.3.bz2
%{_mandir}/man3/MPI_Buffer_detach.3.bz2
%{_mandir}/man3/MPI_Cancel.3.bz2
%{_mandir}/man3/MPI_Cart_coords.3.bz2
%{_mandir}/man3/MPI_Cart_create.3.bz2
%{_mandir}/man3/MPI_Cart_get.3.bz2
%{_mandir}/man3/MPI_Cart_map.3.bz2
%{_mandir}/man3/MPI_Cart_rank.3.bz2
%{_mandir}/man3/MPI_Cart_shift.3.bz2
%{_mandir}/man3/MPI_Cart_sub.3.bz2
%{_mandir}/man3/MPI_Cartdim_get.3.bz2
%{_mandir}/man3/MPI_Comm_compare.3.bz2
%{_mandir}/man3/MPI_Comm_create.3.bz2
%{_mandir}/man3/MPI_Comm_dup.3.bz2
%{_mandir}/man3/MPI_Comm_free.3.bz2
%{_mandir}/man3/MPI_Comm_group.3.bz2
%{_mandir}/man3/MPI_Comm_rank.3.bz2
%{_mandir}/man3/MPI_Comm_remote_group.3.bz2
%{_mandir}/man3/MPI_Comm_remote_size.3.bz2
%{_mandir}/man3/MPI_Comm_size.3.bz2
%{_mandir}/man3/MPI_Comm_split.3.bz2
%{_mandir}/man3/MPI_Comm_test_inter.3.bz2
%{_mandir}/man3/MPI_DUP_FN.3.bz2
%{_mandir}/man3/MPI_Dims_create.3.bz2
%{_mandir}/man3/MPI_Errhandler_create.3.bz2
%{_mandir}/man3/MPI_Errhandler_free.3.bz2
%{_mandir}/man3/MPI_Errhandler_get.3.bz2
%{_mandir}/man3/MPI_Errhandler_set.3.bz2
%{_mandir}/man3/MPI_Error_class.3.bz2
%{_mandir}/man3/MPI_Error_string.3.bz2
%{_mandir}/man3/MPI_File_c2f.3.bz2
%{_mandir}/man3/MPI_File_close.3.bz2
%{_mandir}/man3/MPI_File_delete.3.bz2
%{_mandir}/man3/MPI_File_f2c.3.bz2
%{_mandir}/man3/MPI_File_get_amode.3.bz2
%{_mandir}/man3/MPI_File_get_atomicity.3.bz2
%{_mandir}/man3/MPI_File_get_byte_offset.3.bz2
%{_mandir}/man3/MPI_File_get_errhandler.3.bz2
%{_mandir}/man3/MPI_File_get_group.3.bz2
%{_mandir}/man3/MPI_File_get_info.3.bz2
%{_mandir}/man3/MPI_File_get_position.3.bz2
%{_mandir}/man3/MPI_File_get_position_shared.3.bz2
%{_mandir}/man3/MPI_File_get_size.3.bz2
%{_mandir}/man3/MPI_File_get_type_extent.3.bz2
%{_mandir}/man3/MPI_File_get_view.3.bz2
%{_mandir}/man3/MPI_File_iread.3.bz2
%{_mandir}/man3/MPI_File_iread_at.3.bz2
%{_mandir}/man3/MPI_File_iread_shared.3.bz2
%{_mandir}/man3/MPI_File_iwrite.3.bz2
%{_mandir}/man3/MPI_File_iwrite_at.3.bz2
%{_mandir}/man3/MPI_File_iwrite_shared.3.bz2
%{_mandir}/man3/MPI_File_open.3.bz2
%{_mandir}/man3/MPI_File_preallocate.3.bz2
%{_mandir}/man3/MPI_File_read.3.bz2
%{_mandir}/man3/MPI_File_read_all.3.bz2
%{_mandir}/man3/MPI_File_read_all_begin.3.bz2
%{_mandir}/man3/MPI_File_read_all_end.3.bz2
%{_mandir}/man3/MPI_File_read_at.3.bz2
%{_mandir}/man3/MPI_File_read_at_all.3.bz2
%{_mandir}/man3/MPI_File_read_at_all_begin.3.bz2
%{_mandir}/man3/MPI_File_read_at_all_end.3.bz2
%{_mandir}/man3/MPI_File_read_ordered.3.bz2
%{_mandir}/man3/MPI_File_read_ordered_begin.3.bz2
%{_mandir}/man3/MPI_File_read_ordered_end.3.bz2
%{_mandir}/man3/MPI_File_read_shared.3.bz2
%{_mandir}/man3/MPI_File_seek.3.bz2
%{_mandir}/man3/MPI_File_seek_shared.3.bz2
%{_mandir}/man3/MPI_File_set_atomicity.3.bz2
%{_mandir}/man3/MPI_File_set_errhandler.3.bz2
%{_mandir}/man3/MPI_File_set_info.3.bz2
%{_mandir}/man3/MPI_File_set_size.3.bz2
%{_mandir}/man3/MPI_File_set_view.3.bz2
%{_mandir}/man3/MPI_File_sync.3.bz2
%{_mandir}/man3/MPI_File_write.3.bz2
%{_mandir}/man3/MPI_File_write_all.3.bz2
%{_mandir}/man3/MPI_File_write_all_begin.3.bz2
%{_mandir}/man3/MPI_File_write_all_end.3.bz2
%{_mandir}/man3/MPI_File_write_at.3.bz2
%{_mandir}/man3/MPI_File_write_at_all.3.bz2
%{_mandir}/man3/MPI_File_write_at_all_begin.3.bz2
%{_mandir}/man3/MPI_File_write_at_all_end.3.bz2
%{_mandir}/man3/MPI_File_write_ordered.3.bz2
%{_mandir}/man3/MPI_File_write_ordered_begin.3.bz2
%{_mandir}/man3/MPI_File_write_ordered_end.3.bz2
%{_mandir}/man3/MPI_File_write_shared.3.bz2
%{_mandir}/man3/MPI_Finalize.3.bz2
%{_mandir}/man3/MPI_Finalized.3.bz2
%{_mandir}/man3/MPI_Gather.3.bz2
%{_mandir}/man3/MPI_Gatherv.3.bz2
%{_mandir}/man3/MPI_Get_count.3.bz2
%{_mandir}/man3/MPI_Get_elements.3.bz2
%{_mandir}/man3/MPI_Get_processor_name.3.bz2
%{_mandir}/man3/MPI_Get_version.3.bz2
%{_mandir}/man3/MPI_Graph_create.3.bz2
%{_mandir}/man3/MPI_Graph_get.3.bz2
%{_mandir}/man3/MPI_Graph_map.3.bz2
%{_mandir}/man3/MPI_Graph_neighbors.3.bz2
%{_mandir}/man3/MPI_Graph_neighbors_count.3.bz2
%{_mandir}/man3/MPI_Graphdims_get.3.bz2
%{_mandir}/man3/MPI_Group_compare.3.bz2
%{_mandir}/man3/MPI_Group_difference.3.bz2
%{_mandir}/man3/MPI_Group_excl.3.bz2
%{_mandir}/man3/MPI_Group_free.3.bz2
%{_mandir}/man3/MPI_Group_incl.3.bz2
%{_mandir}/man3/MPI_Group_intersection.3.bz2
%{_mandir}/man3/MPI_Group_range_excl.3.bz2
%{_mandir}/man3/MPI_Group_range_incl.3.bz2
%{_mandir}/man3/MPI_Group_rank.3.bz2
%{_mandir}/man3/MPI_Group_size.3.bz2
%{_mandir}/man3/MPI_Group_translate_ranks.3.bz2
%{_mandir}/man3/MPI_Group_union.3.bz2
%{_mandir}/man3/MPI_Ibsend.3.bz2
%{_mandir}/man3/MPI_Info_c2f.3.bz2
%{_mandir}/man3/MPI_Info_create.3.bz2
%{_mandir}/man3/MPI_Info_delete.3.bz2
%{_mandir}/man3/MPI_Info_dup.3.bz2
%{_mandir}/man3/MPI_Info_f2c.3.bz2
%{_mandir}/man3/MPI_Info_free.3.bz2
%{_mandir}/man3/MPI_Info_get.3.bz2
%{_mandir}/man3/MPI_Info_get_nkeys.3.bz2
%{_mandir}/man3/MPI_Info_get_nthkey.3.bz2
%{_mandir}/man3/MPI_Info_get_valuelen.3.bz2
%{_mandir}/man3/MPI_Info_set.3.bz2
%{_mandir}/man3/MPI_Init.3.bz2
%{_mandir}/man3/MPI_Init_thread.3.bz2
%{_mandir}/man3/MPI_Initialized.3.bz2
%{_mandir}/man3/MPI_Intercomm_create.3.bz2
%{_mandir}/man3/MPI_Intercomm_merge.3.bz2
%{_mandir}/man3/MPI_Iprobe.3.bz2
%{_mandir}/man3/MPI_Irecv.3.bz2
%{_mandir}/man3/MPI_Irsend.3.bz2
%{_mandir}/man3/MPI_Isend.3.bz2
%{_mandir}/man3/MPI_Issend.3.bz2
%{_mandir}/man3/MPI_Keyval_create.3.bz2
%{_mandir}/man3/MPI_Keyval_free.3.bz2
%{_mandir}/man3/MPI_Op_create.3.bz2
%{_mandir}/man3/MPI_Op_free.3.bz2
%{_mandir}/man3/MPI_Pack.3.bz2
%{_mandir}/man3/MPI_Pack_size.3.bz2
%{_mandir}/man3/MPI_Pcontrol.3.bz2
%{_mandir}/man3/MPI_Probe.3.bz2
%{_mandir}/man3/MPI_Recv.3.bz2
%{_mandir}/man3/MPI_Recv_init.3.bz2
%{_mandir}/man3/MPI_Reduce.3.bz2
%{_mandir}/man3/MPI_Reduce_scatter.3.bz2
%{_mandir}/man3/MPI_Request_c2f.3.bz2
%{_mandir}/man3/MPI_Request_free.3.bz2
%{_mandir}/man3/MPI_Rsend.3.bz2
%{_mandir}/man3/MPI_Rsend_init.3.bz2
%{_mandir}/man3/MPI_Scan.3.bz2
%{_mandir}/man3/MPI_Scatter.3.bz2
%{_mandir}/man3/MPI_Scatterv.3.bz2
%{_mandir}/man3/MPI_Send.3.bz2
%{_mandir}/man3/MPI_Send_init.3.bz2
%{_mandir}/man3/MPI_Sendrecv.3.bz2
%{_mandir}/man3/MPI_Sendrecv_replace.3.bz2
%{_mandir}/man3/MPI_Ssend.3.bz2
%{_mandir}/man3/MPI_Ssend_init.3.bz2
%{_mandir}/man3/MPI_Start.3.bz2
%{_mandir}/man3/MPI_Startall.3.bz2
%{_mandir}/man3/MPI_Status_c2f.3.bz2
%{_mandir}/man3/MPI_Test.3.bz2
%{_mandir}/man3/MPI_Test_cancelled.3.bz2
%{_mandir}/man3/MPI_Testall.3.bz2
%{_mandir}/man3/MPI_Testany.3.bz2
%{_mandir}/man3/MPI_Testsome.3.bz2
%{_mandir}/man3/MPI_Topo_test.3.bz2
%{_mandir}/man3/MPI_Type_commit.3.bz2
%{_mandir}/man3/MPI_Type_contiguous.3.bz2
%{_mandir}/man3/MPI_Type_create_darray.3.bz2
%{_mandir}/man3/MPI_Type_create_subarray.3.bz2
%{_mandir}/man3/MPI_Type_extent.3.bz2
%{_mandir}/man3/MPI_Type_free.3.bz2
%{_mandir}/man3/MPI_Type_get_contents.3.bz2
%{_mandir}/man3/MPI_Type_get_envelope.3.bz2
%{_mandir}/man3/MPI_Type_hindexed.3.bz2
%{_mandir}/man3/MPI_Type_hvector.3.bz2
%{_mandir}/man3/MPI_Type_indexed.3.bz2
%{_mandir}/man3/MPI_Type_lb.3.bz2
%{_mandir}/man3/MPI_Type_size.3.bz2
%{_mandir}/man3/MPI_Type_struct.3.bz2
%{_mandir}/man3/MPI_Type_ub.3.bz2
%{_mandir}/man3/MPI_Type_vector.3.bz2
%{_mandir}/man3/MPI_Unpack.3.bz2
%{_mandir}/man3/MPI_Wait.3.bz2
%{_mandir}/man3/MPI_Waitall.3.bz2
%{_mandir}/man3/MPI_Waitany.3.bz2
%{_mandir}/man3/MPI_Waitsome.3.bz2
%{_mandir}/man3/MPI_Wtick.3.bz2
%{_mandir}/man3/MPI_Wtime.3.bz2

%files -n %{lib_name}-devel
%defattr(-,root,root)
%doc LICENSE
%{_bindir}/hcc
%{_bindir}/hf77
%{_bindir}/balky
%{_bindir}/hcp
# FIXME
# this could prduce a conflict with mpich
# this solution is 
#	mv mpicc mpicc.lam
#	mv mpiCC mpiCC.lam
#	mv mpif77 mpif77.lam
%{_bindir}/mpicc
%{_bindir}/mpiCC
%{_bindir}/mpif77
%{_libdir}/*
#%{_libdir}/*.a
#%{_libdir}/*.so
#%{_libdir}/lam/lib
#%{_libdir}/lam/man
#%{_libdir}/lam/include
#%{_includedir}
%{_includedir}/*
#%dir %{_includedir}/mpi2c++/
#%{_includedir}/mpi2c++/*
%{_mandir}/man1/hcc.1.bz2
%{_mandir}/man1/hcp.1.bz2
%{_mandir}/man1/hf77.1.bz2
%{_mandir}/man1/introu.1.bz2
# FIXME
# this could produce a conflict with mpich
# this solution is 
#	mv mpicc mpicc.lam
#	mv mpiCC mpiCC.lam
#	mv mpif77 mpif77.lam
%{_mandir}/man1/mpiCC.1.bz2
%{_mandir}/man1/mpicc.1.bz2
%{_mandir}/man1/mpif77.1.bz2
%{_mandir}/man3/MPI_Accumulate.3.bz2
%{_mandir}/man3/MPI_Alloc_mem.3.bz2
%{_mandir}/man3/MPI_COMM_DUP_FN.3.bz2
%{_mandir}/man3/MPI_Close_port.3.bz2
%{_mandir}/man3/MPI_Comm_accept.3.bz2
%{_mandir}/man3/MPI_Comm_c2f.3.bz2
%{_mandir}/man3/MPI_Comm_connect.3.bz2
%{_mandir}/man3/MPI_Comm_create_errhandler.3.bz2
%{_mandir}/man3/MPI_Comm_create_keyval.3.bz2
%{_mandir}/man3/MPI_Comm_delete_attr.3.bz2
%{_mandir}/man3/MPI_Comm_disconnect.3.bz2
%{_mandir}/man3/MPI_Comm_f2c.3.bz2
%{_mandir}/man3/MPI_Comm_free_keyval.3.bz2
%{_mandir}/man3/MPI_Comm_get_attr.3.bz2
%{_mandir}/man3/MPI_Comm_get_errhandler.3.bz2
%{_mandir}/man3/MPI_Comm_get_name.3.bz2
%{_mandir}/man3/MPI_Comm_get_parent.3.bz2
%{_mandir}/man3/MPI_Comm_join.3.bz2
%{_mandir}/man3/MPI_Comm_ser_errhandler.3.bz2
%{_mandir}/man3/MPI_Comm_set_attr.3.bz2
%{_mandir}/man3/MPI_Comm_set_name.3.bz2
%{_mandir}/man3/MPI_Comm_spawn.3.bz2
%{_mandir}/man3/MPI_Comm_spawn_multiple.3.bz2
%{_mandir}/man3/MPI_Errhandler_c2f.3.bz2
%{_mandir}/man3/MPI_Errhandler_f2c.3.bz2
%{_mandir}/man3/MPI_Free_mem.3.bz2
%{_mandir}/man3/MPI_Get.3.bz2
%{_mandir}/man3/MPI_Get_address.3.bz2
%{_mandir}/man3/MPI_Group_c2f.3.bz2
%{_mandir}/man3/MPI_Group_f2c.3.bz2
%{_mandir}/man3/MPI_Is_thread_main.3.bz2
%{_mandir}/man3/MPI_Lookup_name.3.bz2
%{_mandir}/man3/MPI_Op_c2f.3.bz2
%{_mandir}/man3/MPI_Op_f2c.3.bz2
%{_mandir}/man3/MPI_Open_port.3.bz2
%{_mandir}/man3/MPI_Publish_name.3.bz2
%{_mandir}/man3/MPI_Put.3.bz2
%{_mandir}/man3/MPI_Query_thread.3.bz2
%{_mandir}/man3/MPI_Request_f2c.3.bz2
%{_mandir}/man3/MPI_Status_f2c.3.bz2
%{_mandir}/man3/MPI_TYPE_DUP_FN.3.bz2
%{_mandir}/man3/MPI_Type_c2f.3.bz2
%{_mandir}/man3/MPI_Type_create_extent.3.bz2
%{_mandir}/man3/MPI_Type_create_hindexed.3.bz2
%{_mandir}/man3/MPI_Type_create_hvector.3.bz2
%{_mandir}/man3/MPI_Type_create_keyval.3.bz2
%{_mandir}/man3/MPI_Type_create_struct.3.bz2
%{_mandir}/man3/MPI_Type_delete_attr.3.bz2
%{_mandir}/man3/MPI_Type_dup.3.bz2
%{_mandir}/man3/MPI_Type_f2c.3.bz2
%{_mandir}/man3/MPI_Type_free_keyval.3.bz2
%{_mandir}/man3/MPI_Type_get_attr.3.bz2
%{_mandir}/man3/MPI_Type_get_extent.3.bz2
%{_mandir}/man3/MPI_Type_get_name.3.bz2
%{_mandir}/man3/MPI_Type_get_true_extent.3.bz2
%{_mandir}/man3/MPI_Type_set_attr.3.bz2
%{_mandir}/man3/MPI_Type_set_name.3.bz2
%{_mandir}/man3/MPI_WIN_DUP_FN.3.bz2
%{_mandir}/man3/MPI_Win_c2f.3.bz2
%{_mandir}/man3/MPI_Win_complete.3.bz2
%{_mandir}/man3/MPI_Win_create.3.bz2
%{_mandir}/man3/MPI_Win_create_errhandler.3.bz2
%{_mandir}/man3/MPI_Win_create_keyval.3.bz2
%{_mandir}/man3/MPI_Win_delete_attr.3.bz2
%{_mandir}/man3/MPI_Win_f2c.3.bz2
%{_mandir}/man3/MPI_Win_fence.3.bz2
%{_mandir}/man3/MPI_Win_free.3.bz2
%{_mandir}/man3/MPI_Win_free_keyval.3.bz2
%{_mandir}/man3/MPI_Win_get_attr.3.bz2
%{_mandir}/man3/MPI_Win_get_errhandler.3.bz2
%{_mandir}/man3/MPI_Win_get_group.3.bz2
%{_mandir}/man3/MPI_Win_get_name.3.bz2
%{_mandir}/man3/MPI_Win_post.3.bz2
%{_mandir}/man3/MPI_Win_set_attr.3.bz2
%{_mandir}/man3/MPI_Win_set_errhandler.3.bz2
%{_mandir}/man3/MPI_Win_set_name.3.bz2
%{_mandir}/man3/MPI_Win_start.3.bz2
%{_mandir}/man3/MPI_Win_wait.3.bz2
%{_mandir}/man3/XMPI_Buoy.3.bz2
%{_mandir}/man3/XMPI_Coloroff.3.bz2
%{_mandir}/man3/XMPI_Coloron.3.bz2
%{_mandir}/man3/libmpi.3.bz2
%{_mandir}/man5/CONSTANTS.5.bz2
%{_mandir}/man5/appschema.5.bz2
%{_mandir}/man5/bhost.5.bz2
%{_mandir}/man5/conf.5.bz2
%{_mandir}/man5/lam-helpfile.5.bz2
%{_mandir}/man5/procschema.5.bz2
%{_mandir}/man7/LAM.7.bz2
%{_mandir}/man7/MPI.7.bz2
%{_mandir}/man7/lam.7.bz2
%{_mandir}/man7/mpi.7.bz2

%files -n %{name}-runtime
%defattr(-,root,root)
%doc LICENSE
%{_bindir}/lamclean
%{_bindir}/lamexec
%{_bindir}/lamgrow
%{_bindir}/lamshrink
%{_bindir}/lamtrace
%{_bindir}/mpimsg
# FIXME
# this could prduce a conflict with mpich
# this solution is mv mpirun mpirun.lam
%{_bindir}/mpirun
%{_bindir}/mpitask
%{_bindir}/lamd
%{_bindir}/tping
%{_bindir}/hboot
%{_bindir}/lamboot
%{_bindir}/lamhalt
%{_bindir}/lamnodes
%{_bindir}/recon
%{_bindir}/tkill
%{_bindir}/wipe
%{_mandir}/man1/hboot.1.bz2
%{_mandir}/man1/lamboot.1.bz2
%{_mandir}/man1/lamclean.1.bz2
%{_mandir}/man1/lamexec.1.bz2
%{_mandir}/man1/lamgrow.1.bz2
%{_mandir}/man1/lamshrink.1.bz2
%{_mandir}/man1/lamtrace.1.bz2
%{_mandir}/man1/wipe.1.bz2
%{_mandir}/man1/mpimsg.1.bz2
# FIXME
# this could prduce a conflict with mpich
# this solution is mv mpirun.1.bz2 mpirun.lam.1.bz2
%{_mandir}/man1/mpirun.1.bz2
%{_mandir}/man1/mpitask.1.bz2
%{_mandir}/man1/recon.1.bz2
%{_mandir}/man1/tkill.1.bz2
%{_mandir}/man1/tping.1.bz2
#%{_libdir}/lam/bin
#%{_libdir}/lam/etc
#%{_libdir}/update-cluster/lam.updatelist
%dir %{_sysconfdir}/lam
%config(noreplace) %{_sysconfdir}/lam/lam-bhost.def
%config(noreplace) %{_sysconfdir}/lam/lam-bhost.lam
%config(noreplace) %{_sysconfdir}/lam/lam-conf.lam
%config(noreplace) %{_sysconfdir}/lam/lam-conf.otb
%config(noreplace) %{_sysconfdir}/lam/lam-helpfile
%config(noreplace) %{_sysconfdir}/profile.d/*


%changelog
* Fri Nov 23 2001 Ludovic Francois <lfrancois@mandrakesoft.com> 6.5.5-3mdk
- Added include files missed from last upload

* Thu Nov 22 2001 Ludovic Francois <lfrancois@mandrakesoft.com> 6.5.5-2mdk
- rebuild

* Mon Nov 19 2001 Ludovic Francois <lfrancois@mandrakesoft.com> 6.5.5-1mdk
- First version of the package

# end of file
